@@ -13,22 +13,30 @@ try:
     import requests
 
 
-    def _post(url, form: Dict[str, Any], headers: Dict[str, Any], timeout=10) -> str:
-        response = requests.post(url, json=form, headers=headers, timeout=timeout)
+    def _post(url, form: Dict[str, Any], headers: Dict[str, Any], timeout=10, verify=True) -> str:
+        response = requests.post(url, json=form, headers=headers, timeout=timeout, verify=verify)
         if response.status_code != 200:
             raise HTTPError(url, response.status_code, response.text, response.headers, None)
         return response.text
 except ImportError:
-    def _post(url, form: Dict[str, Any], headers: Dict[str, Any], timeout=10) -> str:
+    import ssl
+
+
+    def _post(url, form: Dict[str, Any], headers: Dict[str, Any], timeout=10, verify=True) -> str:
         request = Request(url, json.dumps(form).encode())
         for k, v in headers.items():
             request.add_header(k, v)
-        return urlopen(request, timeout=timeout).read().decode()
+        ctx = None
+        if not verify:
+            ctx = ssl.create_default_context()
+            ctx.check_hostname = False
+            ctx.verify_mode = ssl.CERT_NONE
+        return urlopen(request, timeout=timeout, context=ctx).read().decode()
 
 
 class HanLPClient(object):
 
-    def __init__(self, url: str, auth: str = None, language=None, timeout=10) -> None:
+    def __init__(self, url: str, auth: str = None, language=None, timeout=10, verify=True) -> None:
         """
 
         Args:
@@ -39,6 +47,8 @@ class HanLPClient(object):
                 Conventionally, ``zh`` is used for Chinese and ``mul`` for multilingual.
                 Leave ``None`` to use the default language on server.
             timeout (int): Maximum waiting time in seconds for a request.
+            verify (bool): ``True`` to enable SSL cert verification. You can also pass verify the path to a CA_BUNDLE
+                file or directory with certificates of trusted CAs
         """
         super().__init__()
         self._language = language
@@ -48,6 +58,7 @@ class HanLPClient(object):
             import os
             auth = os.getenv('HANLP_AUTH', None)
         self._auth = auth
+        self._verify = verify
 
     def parse(self,
               text: Union[str, List[str]] = None,
@@ -126,7 +137,7 @@ class HanLPClient(object):
         headers = dict()
         if self._auth:
             headers['Authorization'] = f'Basic {self._auth}'
-        return json.loads(_post(url, form, headers, self._timeout))
+        return json.loads(_post(url, form, headers, self._timeout, verify=self._verify))
 
     def _send_get(self, url, form: Dict[str, Any]):
         request = Request(url + '?' + urlencode(form))
@@ -419,7 +430,7 @@ class HanLPClient(object):
         spelling, punctuation, grammatical, and word choice errors.
 
         Args:
-            text: Text potentially containing different kinds of errors in text such as spelling, punctuation,
+            text: Text potentially containing different kinds of errors such as spelling, punctuation,
                 grammatical, and word choice errors.
             language: The language of input text. ``None`` to use the default language.
 
@@ -428,7 +439,8 @@ class HanLPClient(object):
 
         Examples::
 
-            HanLP.grammatical_error_correction(['每个青年都应当有远大的报复。', '有的同学对语言很兴趣。'])
+            HanLP.grammatical_error_correction(['每个青年都应当有远大的报复。',
+                                                '有的同学对语言很兴趣。'])
             # Output:
             [
                 '每个青年都应当有远大的抱负。',
